@@ -145,6 +145,7 @@ public:
     QString busyMessage;
     QString useLabel;
     bool uploadEnabled = false;
+    QString configFileName;
 };
 
 Engine::Engine(QObject *parent)
@@ -224,6 +225,7 @@ bool Engine::init(const QString &configfile)
         conf.reset(new KConfig(configfile));
         qCWarning(KNEWSTUFFCORE) << "Using a deprecated location for the knsrc file" << configfile
                                  << " - please contact the author of the software which provides this file to get it updated to use the new location";
+        configFileName = QFileInfo(configfile).baseName();
     } else if (isRelativeConfig && actualConfig.isEmpty()) {
         configFileName = QFileInfo(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("knsrcfiles/%1").arg(configfile))).baseName();
         conf.reset(new KConfig(QStringLiteral("knsrcfiles/%1").arg(configfile), KConfig::FullConfig, QStandardPaths::GenericDataLocation));
@@ -234,6 +236,7 @@ bool Engine::init(const QString &configfile)
         configFileName = configFileInfo.baseName();
         conf.reset(new KConfig(configfile));
     }
+    d->configFileName = configFileName;
 
     if (conf->accessMode() == KConfig::NoAccess) {
         Q_EMIT signalErrorCode(KNSCore::ConfigFileError, i18n("Configuration file exists, but cannot be opened: \"%1\"", configfile), configfile);
@@ -263,7 +266,7 @@ bool Engine::init(const QString &configfile)
     d->uploadEnabled = group.readEntry("UploadEnabled", true);
     Q_EMIT uploadEnabledChanged();
 
-    m_providerFileUrl = group.readEntry("ProvidersUrl");
+    m_providerFileUrl = group.readEntry("ProvidersUrl", QStringLiteral("https://autoconfig.kde.org/ocs/providers.xml"));
     if (m_providerFileUrl == QLatin1String("https://download.kde.org/ocs/providers.xml")) {
         m_providerFileUrl = QStringLiteral("https://autoconfig.kde.org/ocs/providers.xml");
         qCWarning(KNEWSTUFFCORE) << "Please make sure" << configfile << "has ProvidersUrl=https://autoconfig.kde.org/ocs/providers.xml";
@@ -425,7 +428,7 @@ void Engine::slotProviderFileLoaded(const QDomDocument &doc)
 
         QSharedPointer<KNSCore::Provider> provider;
         if (isAtticaProviderFile || n.attribute(QStringLiteral("type")).toLower() == QLatin1String("rest")) {
-            provider.reset(new AtticaProvider(m_categories, d->name));
+            provider.reset(new AtticaProvider(m_categories, d->configFileName));
             connect(provider.data(), &Provider::categoriesMetadataLoded, this, [this](const QList<Provider::CategoryMetadata> &categories) {
                 d->categoriesMetadata = categories;
                 Q_EMIT signalCategoriesMetadataLoded(categories);
@@ -459,7 +462,7 @@ void Engine::atticaProviderLoaded(const Attica::Provider &atticaProvider)
         qCDebug(KNEWSTUFFCORE) << "Found provider: " << atticaProvider.baseUrl() << " but it does not support content";
         return;
     }
-    QSharedPointer<KNSCore::Provider> provider = QSharedPointer<KNSCore::Provider>(new AtticaProvider(atticaProvider, m_categories, d->name));
+    QSharedPointer<KNSCore::Provider> provider = QSharedPointer<KNSCore::Provider>(new AtticaProvider(atticaProvider, m_categories, d->configFileName));
     connect(provider.data(), &Provider::categoriesMetadataLoded, this, [this](const QList<Provider::CategoryMetadata> &categories) {
         d->categoriesMetadata = categories;
         Q_EMIT signalCategoriesMetadataLoded(categories);
